noteeditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# noteeditor

class `camelot.view.controls.editors.noteeditor.` `NoteEditor`(parent=None, field_name='note', **kwargs)

  An editor that behaves like a note, the editor hides itself when there is no text to display

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus